# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmwasm/wasm/v1/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmwasm/wasm/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmwasm/wasm/v1/types.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"V\n\x0f\x41\x63\x63\x65ssTypeParam\x12=\n\x05value\x18\x01 \x01(\x0e\x32\x1c.cosmwasm.wasm.v1.AccessTypeB\x10\xf2\xde\x1f\x0cyaml:\"value\":\x04\x98\xa0\x1f\x01\"\x82\x01\n\x0c\x41\x63\x63\x65ssConfig\x12G\n\npermission\x18\x01 \x01(\x0e\x32\x1c.cosmwasm.wasm.v1.AccessTypeB\x15\xf2\xde\x1f\x11yaml:\"permission\"\x12#\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\":\x04\x98\xa0\x1f\x01\"\xde\x01\n\x06Params\x12]\n\x12\x63ode_upload_access\x18\x01 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB!\xc8\xde\x1f\x00\xf2\xde\x1f\x19yaml:\"code_upload_access\"\x12o\n\x1einstantiate_default_permission\x18\x02 \x01(\x0e\x32\x1c.cosmwasm.wasm.v1.AccessTypeB)\xf2\xde\x1f%yaml:\"instantiate_default_permission\":\x04\x98\xa0\x1f\x00\"|\n\x08\x43odeInfo\x12\x11\n\tcode_hash\x18\x01 \x01(\x0c\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12@\n\x12instantiate_config\x18\x05 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB\x04\xc8\xde\x1f\x00J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\xff\x01\n\x0c\x43ontractInfo\x12\x1b\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12\r\n\x05\x61\x64min\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\x12\x35\n\x07\x63reated\x18\x05 \x01(\x0b\x32$.cosmwasm.wasm.v1.AbsoluteTxPosition\x12\"\n\x0bibc_port_id\x18\x06 \x01(\tB\r\xe2\xde\x1f\tIBCPortID\x12\x42\n\textension\x18\x07 \x01(\x0b\x32\x14.google.protobuf.AnyB\x19\xca\xb4-\x15\x43ontractInfoExtension:\x04\xe8\xa0\x1f\x01\"\xda\x01\n\x18\x43ontractCodeHistoryEntry\x12\x45\n\toperation\x18\x01 \x01(\x0e\x32\x32.cosmwasm.wasm.v1.ContractCodeHistoryOperationType\x12\x1b\n\x07\x63ode_id\x18\x02 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x35\n\x07updated\x18\x03 \x01(\x0b\x32$.cosmwasm.wasm.v1.AbsoluteTxPosition\x12#\n\x03msg\x18\x04 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\"<\n\x12\x41\x62soluteTxPosition\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\x04\x12\x10\n\x08tx_index\x18\x02 \x01(\x04\"]\n\x05Model\x12\x45\n\x03key\x18\x01 \x01(\x0c\x42\x38\xfa\xde\x1f\x34github.com/tendermint/tendermint/libs/bytes.HexBytes\x12\r\n\x05value\x18\x02 \x01(\x0c*\xe9\x01\n\nAccessType\x12\x36\n\x17\x41\x43\x43\x45SS_TYPE_UNSPECIFIED\x10\x00\x1a\x19\x8a\x9d \x15\x41\x63\x63\x65ssTypeUnspecified\x12,\n\x12\x41\x43\x43\x45SS_TYPE_NOBODY\x10\x01\x1a\x14\x8a\x9d \x10\x41\x63\x63\x65ssTypeNobody\x12\x37\n\x18\x41\x43\x43\x45SS_TYPE_ONLY_ADDRESS\x10\x02\x1a\x19\x8a\x9d \x15\x41\x63\x63\x65ssTypeOnlyAddress\x12\x32\n\x15\x41\x43\x43\x45SS_TYPE_EVERYBODY\x10\x03\x1a\x17\x8a\x9d \x13\x41\x63\x63\x65ssTypeEverybody\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x00*\xa6\x03\n ContractCodeHistoryOperationType\x12\x65\n0CONTRACT_CODE_HISTORY_OPERATION_TYPE_UNSPECIFIED\x10\x00\x1a/\x8a\x9d +ContractCodeHistoryOperationTypeUnspecified\x12W\n)CONTRACT_CODE_HISTORY_OPERATION_TYPE_INIT\x10\x01\x1a(\x8a\x9d $ContractCodeHistoryOperationTypeInit\x12]\n,CONTRACT_CODE_HISTORY_OPERATION_TYPE_MIGRATE\x10\x02\x1a+\x8a\x9d \'ContractCodeHistoryOperationTypeMigrate\x12]\n,CONTRACT_CODE_HISTORY_OPERATION_TYPE_GENESIS\x10\x03\x1a+\x8a\x9d \'ContractCodeHistoryOperationTypeGenesis\x1a\x04\x88\xa3\x1e\x00\x42\x30Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000\250\342\036\001'
  _globals['_ACCESSTYPE']._loaded_options = None
  _globals['_ACCESSTYPE']._serialized_options = b'\210\243\036\000\250\244\036\000'
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_UNSPECIFIED"]._loaded_options = None
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 \025AccessTypeUnspecified'
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_NOBODY"]._loaded_options = None
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_NOBODY"]._serialized_options = b'\212\235 \020AccessTypeNobody'
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_ONLY_ADDRESS"]._loaded_options = None
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_ONLY_ADDRESS"]._serialized_options = b'\212\235 \025AccessTypeOnlyAddress'
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_EVERYBODY"]._loaded_options = None
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_EVERYBODY"]._serialized_options = b'\212\235 \023AccessTypeEverybody'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE']._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_UNSPECIFIED"]._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 +ContractCodeHistoryOperationTypeUnspecified'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_INIT"]._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_INIT"]._serialized_options = b'\212\235 $ContractCodeHistoryOperationTypeInit'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_MIGRATE"]._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_MIGRATE"]._serialized_options = b'\212\235 \'ContractCodeHistoryOperationTypeMigrate'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_GENESIS"]._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_GENESIS"]._serialized_options = b'\212\235 \'ContractCodeHistoryOperationTypeGenesis'
  _globals['_ACCESSTYPEPARAM'].fields_by_name['value']._loaded_options = None
  _globals['_ACCESSTYPEPARAM'].fields_by_name['value']._serialized_options = b'\362\336\037\014yaml:\"value\"'
  _globals['_ACCESSTYPEPARAM']._loaded_options = None
  _globals['_ACCESSTYPEPARAM']._serialized_options = b'\230\240\037\001'
  _globals['_ACCESSCONFIG'].fields_by_name['permission']._loaded_options = None
  _globals['_ACCESSCONFIG'].fields_by_name['permission']._serialized_options = b'\362\336\037\021yaml:\"permission\"'
  _globals['_ACCESSCONFIG'].fields_by_name['address']._loaded_options = None
  _globals['_ACCESSCONFIG'].fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _globals['_ACCESSCONFIG']._loaded_options = None
  _globals['_ACCESSCONFIG']._serialized_options = b'\230\240\037\001'
  _globals['_PARAMS'].fields_by_name['code_upload_access']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['code_upload_access']._serialized_options = b'\310\336\037\000\362\336\037\031yaml:\"code_upload_access\"'
  _globals['_PARAMS'].fields_by_name['instantiate_default_permission']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['instantiate_default_permission']._serialized_options = b'\362\336\037%yaml:\"instantiate_default_permission\"'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\230\240\037\000'
  _globals['_CODEINFO'].fields_by_name['instantiate_config']._loaded_options = None
  _globals['_CODEINFO'].fields_by_name['instantiate_config']._serialized_options = b'\310\336\037\000'
  _globals['_CONTRACTINFO'].fields_by_name['code_id']._loaded_options = None
  _globals['_CONTRACTINFO'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_CONTRACTINFO'].fields_by_name['ibc_port_id']._loaded_options = None
  _globals['_CONTRACTINFO'].fields_by_name['ibc_port_id']._serialized_options = b'\342\336\037\tIBCPortID'
  _globals['_CONTRACTINFO'].fields_by_name['extension']._loaded_options = None
  _globals['_CONTRACTINFO'].fields_by_name['extension']._serialized_options = b'\312\264-\025ContractInfoExtension'
  _globals['_CONTRACTINFO']._loaded_options = None
  _globals['_CONTRACTINFO']._serialized_options = b'\350\240\037\001'
  _globals['_CONTRACTCODEHISTORYENTRY'].fields_by_name['code_id']._loaded_options = None
  _globals['_CONTRACTCODEHISTORYENTRY'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_CONTRACTCODEHISTORYENTRY'].fields_by_name['msg']._loaded_options = None
  _globals['_CONTRACTCODEHISTORYENTRY'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _globals['_MODEL'].fields_by_name['key']._loaded_options = None
  _globals['_MODEL'].fields_by_name['key']._serialized_options = b'\372\336\0374github.com/tendermint/tendermint/libs/bytes.HexBytes'
  _globals['_ACCESSTYPE']._serialized_start=1335
  _globals['_ACCESSTYPE']._serialized_end=1568
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE']._serialized_start=1571
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE']._serialized_end=1993
  _globals['_ACCESSTYPEPARAM']._serialized_start=126
  _globals['_ACCESSTYPEPARAM']._serialized_end=212
  _globals['_ACCESSCONFIG']._serialized_start=215
  _globals['_ACCESSCONFIG']._serialized_end=345
  _globals['_PARAMS']._serialized_start=348
  _globals['_PARAMS']._serialized_end=570
  _globals['_CODEINFO']._serialized_start=572
  _globals['_CODEINFO']._serialized_end=696
  _globals['_CONTRACTINFO']._serialized_start=699
  _globals['_CONTRACTINFO']._serialized_end=954
  _globals['_CONTRACTCODEHISTORYENTRY']._serialized_start=957
  _globals['_CONTRACTCODEHISTORYENTRY']._serialized_end=1175
  _globals['_ABSOLUTETXPOSITION']._serialized_start=1177
  _globals['_ABSOLUTETXPOSITION']._serialized_end=1237
  _globals['_MODEL']._serialized_start=1239
  _globals['_MODEL']._serialized_end=1332
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from cometbft.libs.bits.v1 import types_pb2 as _types_pb2
from cometbft.types.v2 import types_pb2 as _types_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NewRoundStep(_message.Message):
    __slots__ = ("height", "round", "step", "seconds_since_start_time", "last_commit_round")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    STEP_FIELD_NUMBER: _ClassVar[int]
    SECONDS_SINCE_START_TIME_FIELD_NUMBER: _ClassVar[int]
    LAST_COMMIT_ROUND_FIELD_NUMBER: _ClassVar[int]
    height: int
    round: int
    step: int
    seconds_since_start_time: int
    last_commit_round: int
    def __init__(self, height: _Optional[int] = ..., round: _Optional[int] = ..., step: _Optional[int] = ..., seconds_since_start_time: _Optional[int] = ..., last_commit_round: _Optional[int] = ...) -> None: ...

class NewValidBlock(_message.Message):
    __slots__ = ("height", "round", "block_part_set_header", "block_parts", "is_commit")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    BLOCK_PART_SET_HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_PARTS_FIELD_NUMBER: _ClassVar[int]
    IS_COMMIT_FIELD_NUMBER: _ClassVar[int]
    height: int
    round: int
    block_part_set_header: _types_pb2_1.PartSetHeader
    block_parts: _types_pb2.BitArray
    is_commit: bool
    def __init__(self, height: _Optional[int] = ..., round: _Optional[int] = ..., block_part_set_header: _Optional[_Union[_types_pb2_1.PartSetHeader, _Mapping]] = ..., block_parts: _Optional[_Union[_types_pb2.BitArray, _Mapping]] = ..., is_commit: bool = ...) -> None: ...

class Proposal(_message.Message):
    __slots__ = ("proposal",)
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    proposal: _types_pb2_1.Proposal
    def __init__(self, proposal: _Optional[_Union[_types_pb2_1.Proposal, _Mapping]] = ...) -> None: ...

class ProposalPOL(_message.Message):
    __slots__ = ("height", "proposal_pol_round", "proposal_pol")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_POL_ROUND_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_POL_FIELD_NUMBER: _ClassVar[int]
    height: int
    proposal_pol_round: int
    proposal_pol: _types_pb2.BitArray
    def __init__(self, height: _Optional[int] = ..., proposal_pol_round: _Optional[int] = ..., proposal_pol: _Optional[_Union[_types_pb2.BitArray, _Mapping]] = ...) -> None: ...

class BlockPart(_message.Message):
    __slots__ = ("height", "round", "part")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    PART_FIELD_NUMBER: _ClassVar[int]
    height: int
    round: int
    part: _types_pb2_1.Part
    def __init__(self, height: _Optional[int] = ..., round: _Optional[int] = ..., part: _Optional[_Union[_types_pb2_1.Part, _Mapping]] = ...) -> None: ...

class Vote(_message.Message):
    __slots__ = ("vote",)
    VOTE_FIELD_NUMBER: _ClassVar[int]
    vote: _types_pb2_1.Vote
    def __init__(self, vote: _Optional[_Union[_types_pb2_1.Vote, _Mapping]] = ...) -> None: ...

class HasVote(_message.Message):
    __slots__ = ("height", "round", "type", "index")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    height: int
    round: int
    type: _types_pb2_1.SignedMsgType
    index: int
    def __init__(self, height: _Optional[int] = ..., round: _Optional[int] = ..., type: _Optional[_Union[_types_pb2_1.SignedMsgType, str]] = ..., index: _Optional[int] = ...) -> None: ...

class VoteSetMaj23(_message.Message):
    __slots__ = ("height", "round", "type", "block_id")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    height: int
    round: int
    type: _types_pb2_1.SignedMsgType
    block_id: _types_pb2_1.BlockID
    def __init__(self, height: _Optional[int] = ..., round: _Optional[int] = ..., type: _Optional[_Union[_types_pb2_1.SignedMsgType, str]] = ..., block_id: _Optional[_Union[_types_pb2_1.BlockID, _Mapping]] = ...) -> None: ...

class VoteSetBits(_message.Message):
    __slots__ = ("height", "round", "type", "block_id", "votes")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    height: int
    round: int
    type: _types_pb2_1.SignedMsgType
    block_id: _types_pb2_1.BlockID
    votes: _types_pb2.BitArray
    def __init__(self, height: _Optional[int] = ..., round: _Optional[int] = ..., type: _Optional[_Union[_types_pb2_1.SignedMsgType, str]] = ..., block_id: _Optional[_Union[_types_pb2_1.BlockID, _Mapping]] = ..., votes: _Optional[_Union[_types_pb2.BitArray, _Mapping]] = ...) -> None: ...

class HasProposalBlockPart(_message.Message):
    __slots__ = ("height", "round", "index")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    height: int
    round: int
    index: int
    def __init__(self, height: _Optional[int] = ..., round: _Optional[int] = ..., index: _Optional[int] = ...) -> None: ...

class Message(_message.Message):
    __slots__ = ("new_round_step", "new_valid_block", "proposal", "proposal_pol", "block_part", "vote", "has_vote", "vote_set_maj23", "vote_set_bits", "has_proposal_block_part")
    NEW_ROUND_STEP_FIELD_NUMBER: _ClassVar[int]
    NEW_VALID_BLOCK_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_POL_FIELD_NUMBER: _ClassVar[int]
    BLOCK_PART_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    HAS_VOTE_FIELD_NUMBER: _ClassVar[int]
    VOTE_SET_MAJ23_FIELD_NUMBER: _ClassVar[int]
    VOTE_SET_BITS_FIELD_NUMBER: _ClassVar[int]
    HAS_PROPOSAL_BLOCK_PART_FIELD_NUMBER: _ClassVar[int]
    new_round_step: NewRoundStep
    new_valid_block: NewValidBlock
    proposal: Proposal
    proposal_pol: ProposalPOL
    block_part: BlockPart
    vote: Vote
    has_vote: HasVote
    vote_set_maj23: VoteSetMaj23
    vote_set_bits: VoteSetBits
    has_proposal_block_part: HasProposalBlockPart
    def __init__(self, new_round_step: _Optional[_Union[NewRoundStep, _Mapping]] = ..., new_valid_block: _Optional[_Union[NewValidBlock, _Mapping]] = ..., proposal: _Optional[_Union[Proposal, _Mapping]] = ..., proposal_pol: _Optional[_Union[ProposalPOL, _Mapping]] = ..., block_part: _Optional[_Union[BlockPart, _Mapping]] = ..., vote: _Optional[_Union[Vote, _Mapping]] = ..., has_vote: _Optional[_Union[HasVote, _Mapping]] = ..., vote_set_maj23: _Optional[_Union[VoteSetMaj23, _Mapping]] = ..., vote_set_bits: _Optional[_Union[VoteSetBits, _Mapping]] = ..., has_proposal_block_part: _Optional[_Union[HasProposalBlockPart, _Mapping]] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DisputeValidationTaskResult(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DISPUTE_VALIDATION_TASK_RESULT_NOT_AVAILABLE: _ClassVar[DisputeValidationTaskResult]
    DISPUTE_VALIDATION_TASK_RESULT_ACCEPTED: _ClassVar[DisputeValidationTaskResult]
    DISPUTE_VALIDATION_TASK_RESULT_REJECTED: _ClassVar[DisputeValidationTaskResult]
DISPUTE_VALIDATION_TASK_RESULT_NOT_AVAILABLE: DisputeValidationTaskResult
DISPUTE_VALIDATION_TASK_RESULT_ACCEPTED: DisputeValidationTaskResult
DISPUTE_VALIDATION_TASK_RESULT_REJECTED: DisputeValidationTaskResult

class DisputeValidationTask(_message.Message):
    __slots__ = ("id", "creator", "proposed_model_id", "proposed_score", "deposit", "result", "created_timestamp", "decision_timestamp", "accepting_dispute_validators", "rejecting_dispute_validators", "task_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    PROPOSED_MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    PROPOSED_SCORE_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    CREATED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DECISION_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    ACCEPTING_DISPUTE_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    REJECTING_DISPUTE_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    creator: str
    proposed_model_id: int
    proposed_score: str
    deposit: int
    result: DisputeValidationTaskResult
    created_timestamp: int
    decision_timestamp: int
    accepting_dispute_validators: _containers.RepeatedScalarFieldContainer[str]
    rejecting_dispute_validators: _containers.RepeatedScalarFieldContainer[str]
    task_id: int
    def __init__(self, id: _Optional[int] = ..., creator: _Optional[str] = ..., proposed_model_id: _Optional[int] = ..., proposed_score: _Optional[str] = ..., deposit: _Optional[int] = ..., result: _Optional[_Union[DisputeValidationTaskResult, str]] = ..., created_timestamp: _Optional[int] = ..., decision_timestamp: _Optional[int] = ..., accepting_dispute_validators: _Optional[_Iterable[str]] = ..., rejecting_dispute_validators: _Optional[_Iterable[str]] = ..., task_id: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DatasetUsageRequestResult(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DATASET_USAGE_REQUEST_RESULT_NOT_AVAILABLE: _ClassVar[DatasetUsageRequestResult]
    DATASET_USAGE_REQUEST_RESULT_ACCEPTED: _ClassVar[DatasetUsageRequestResult]
    DATASET_USAGE_REQUEST_RESULT_REJECTED: _ClassVar[DatasetUsageRequestResult]
    DATASET_USAGE_REQUEST_RESULT_CANCELLED: _ClassVar[DatasetUsageRequestResult]
    DATASET_USAGE_REQUEST_RESULT_PROCESSING: _ClassVar[DatasetUsageRequestResult]
    DATASET_USAGE_REQUEST_RESULT_FINISHED: _ClassVar[DatasetUsageRequestResult]
    DATASET_USAGE_REQUEST_RESULT_DISPUTED: _ClassVar[DatasetUsageRequestResult]
DATASET_USAGE_REQUEST_RESULT_NOT_AVAILABLE: DatasetUsageRequestResult
DATASET_USAGE_REQUEST_RESULT_ACCEPTED: DatasetUsageRequestResult
DATASET_USAGE_REQUEST_RESULT_REJECTED: DatasetUsageRequestResult
DATASET_USAGE_REQUEST_RESULT_CANCELLED: DatasetUsageRequestResult
DATASET_USAGE_REQUEST_RESULT_PROCESSING: DatasetUsageRequestResult
DATASET_USAGE_REQUEST_RESULT_FINISHED: DatasetUsageRequestResult
DATASET_USAGE_REQUEST_RESULT_DISPUTED: DatasetUsageRequestResult

class DatasetUsageRequest(_message.Message):
    __slots__ = ("id", "creator", "result", "dataset_id", "intent", "training_repository", "fee_paid", "decision_timestamp", "decision_maker", "decision_reason", "creation_timestamp", "dispute_model", "dispute_resolution_reason", "feedback", "contact")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    DATASET_ID_FIELD_NUMBER: _ClassVar[int]
    INTENT_FIELD_NUMBER: _ClassVar[int]
    TRAINING_REPOSITORY_FIELD_NUMBER: _ClassVar[int]
    FEE_PAID_FIELD_NUMBER: _ClassVar[int]
    DECISION_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DECISION_MAKER_FIELD_NUMBER: _ClassVar[int]
    DECISION_REASON_FIELD_NUMBER: _ClassVar[int]
    CREATION_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DISPUTE_MODEL_FIELD_NUMBER: _ClassVar[int]
    DISPUTE_RESOLUTION_REASON_FIELD_NUMBER: _ClassVar[int]
    FEEDBACK_FIELD_NUMBER: _ClassVar[int]
    CONTACT_FIELD_NUMBER: _ClassVar[int]
    id: int
    creator: str
    result: DatasetUsageRequestResult
    dataset_id: int
    intent: str
    training_repository: str
    fee_paid: int
    decision_timestamp: int
    decision_maker: str
    decision_reason: str
    creation_timestamp: int
    dispute_model: str
    dispute_resolution_reason: str
    feedback: str
    contact: str
    def __init__(self, id: _Optional[int] = ..., creator: _Optional[str] = ..., result: _Optional[_Union[DatasetUsageRequestResult, str]] = ..., dataset_id: _Optional[int] = ..., intent: _Optional[str] = ..., training_repository: _Optional[str] = ..., fee_paid: _Optional[int] = ..., decision_timestamp: _Optional[int] = ..., decision_maker: _Optional[str] = ..., decision_reason: _Optional[str] = ..., creation_timestamp: _Optional[int] = ..., dispute_model: _Optional[str] = ..., dispute_resolution_reason: _Optional[str] = ..., feedback: _Optional[str] = ..., contact: _Optional[str] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AuthorizationType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    AUTHORIZATION_TYPE_UNSPECIFIED: _ClassVar[AuthorizationType]
    AUTHORIZATION_TYPE_DELEGATE: _ClassVar[AuthorizationType]
    AUTHORIZATION_TYPE_UNDELEGATE: _ClassVar[AuthorizationType]
    AUTHORIZATION_TYPE_REDELEGATE: _ClassVar[AuthorizationType]
AUTHORIZATION_TYPE_UNSPECIFIED: AuthorizationType
AUTHORIZATION_TYPE_DELEGATE: AuthorizationType
AUTHORIZATION_TYPE_UNDELEGATE: AuthorizationType
AUTHORIZATION_TYPE_REDELEGATE: AuthorizationType

class StakeAuthorization(_message.Message):
    __slots__ = ("max_tokens", "allow_list", "deny_list", "authorization_type")
    class Validators(_message.Message):
        __slots__ = ("address",)
        ADDRESS_FIELD_NUMBER: _ClassVar[int]
        address: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, address: _Optional[_Iterable[str]] = ...) -> None: ...
    MAX_TOKENS_FIELD_NUMBER: _ClassVar[int]
    ALLOW_LIST_FIELD_NUMBER: _ClassVar[int]
    DENY_LIST_FIELD_NUMBER: _ClassVar[int]
    AUTHORIZATION_TYPE_FIELD_NUMBER: _ClassVar[int]
    max_tokens: _coin_pb2.Coin
    allow_list: StakeAuthorization.Validators
    deny_list: StakeAuthorization.Validators
    authorization_type: AuthorizationType
    def __init__(self, max_tokens: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ..., allow_list: _Optional[_Union[StakeAuthorization.Validators, _Mapping]] = ..., deny_list: _Optional[_Union[StakeAuthorization.Validators, _Mapping]] = ..., authorization_type: _Optional[_Union[AuthorizationType, str]] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.api import annotations_pb2 as _annotations_pb2
from tendermint.p2p import types_pb2 as _types_pb2
from tendermint.types import block_pb2 as _block_pb2
from tendermint.types import types_pb2 as _types_pb2_1
from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetValidatorSetByHeightRequest(_message.Message):
    __slots__ = ("height", "pagination")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    height: int
    pagination: _pagination_pb2.PageRequest
    def __init__(self, height: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class GetValidatorSetByHeightResponse(_message.Message):
    __slots__ = ("block_height", "validators", "pagination")
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    block_height: int
    validators: _containers.RepeatedCompositeFieldContainer[Validator]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, block_height: _Optional[int] = ..., validators: _Optional[_Iterable[_Union[Validator, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class GetLatestValidatorSetRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class GetLatestValidatorSetResponse(_message.Message):
    __slots__ = ("block_height", "validators", "pagination")
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    block_height: int
    validators: _containers.RepeatedCompositeFieldContainer[Validator]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, block_height: _Optional[int] = ..., validators: _Optional[_Iterable[_Union[Validator, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class Validator(_message.Message):
    __slots__ = ("address", "pub_key", "voting_power", "proposer_priority")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_PRIORITY_FIELD_NUMBER: _ClassVar[int]
    address: str
    pub_key: _any_pb2.Any
    voting_power: int
    proposer_priority: int
    def __init__(self, address: _Optional[str] = ..., pub_key: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., voting_power: _Optional[int] = ..., proposer_priority: _Optional[int] = ...) -> None: ...

class GetBlockByHeightRequest(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class GetBlockByHeightResponse(_message.Message):
    __slots__ = ("block_id", "block")
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    block_id: _types_pb2_1.BlockID
    block: _block_pb2.Block
    def __init__(self, block_id: _Optional[_Union[_types_pb2_1.BlockID, _Mapping]] = ..., block: _Optional[_Union[_block_pb2.Block, _Mapping]] = ...) -> None: ...

class GetLatestBlockRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetLatestBlockResponse(_message.Message):
    __slots__ = ("block_id", "block")
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    block_id: _types_pb2_1.BlockID
    block: _block_pb2.Block
    def __init__(self, block_id: _Optional[_Union[_types_pb2_1.BlockID, _Mapping]] = ..., block: _Optional[_Union[_block_pb2.Block, _Mapping]] = ...) -> None: ...

class GetSyncingRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetSyncingResponse(_message.Message):
    __slots__ = ("syncing",)
    SYNCING_FIELD_NUMBER: _ClassVar[int]
    syncing: bool
    def __init__(self, syncing: bool = ...) -> None: ...

class GetNodeInfoRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetNodeInfoResponse(_message.Message):
    __slots__ = ("default_node_info", "application_version")
    DEFAULT_NODE_INFO_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_VERSION_FIELD_NUMBER: _ClassVar[int]
    default_node_info: _types_pb2.DefaultNodeInfo
    application_version: VersionInfo
    def __init__(self, default_node_info: _Optional[_Union[_types_pb2.DefaultNodeInfo, _Mapping]] = ..., application_version: _Optional[_Union[VersionInfo, _Mapping]] = ...) -> None: ...

class VersionInfo(_message.Message):
    __slots__ = ("name", "app_name", "version", "git_commit", "build_tags", "go_version", "build_deps", "cosmos_sdk_version")
    NAME_FIELD_NUMBER: _ClassVar[int]
    APP_NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    GIT_COMMIT_FIELD_NUMBER: _ClassVar[int]
    BUILD_TAGS_FIELD_NUMBER: _ClassVar[int]
    GO_VERSION_FIELD_NUMBER: _ClassVar[int]
    BUILD_DEPS_FIELD_NUMBER: _ClassVar[int]
    COSMOS_SDK_VERSION_FIELD_NUMBER: _ClassVar[int]
    name: str
    app_name: str
    version: str
    git_commit: str
    build_tags: str
    go_version: str
    build_deps: _containers.RepeatedCompositeFieldContainer[Module]
    cosmos_sdk_version: str
    def __init__(self, name: _Optional[str] = ..., app_name: _Optional[str] = ..., version: _Optional[str] = ..., git_commit: _Optional[str] = ..., build_tags: _Optional[str] = ..., go_version: _Optional[str] = ..., build_deps: _Optional[_Iterable[_Union[Module, _Mapping]]] = ..., cosmos_sdk_version: _Optional[str] = ...) -> None: ...

class Module(_message.Message):
    __slots__ = ("path", "version", "sum")
    PATH_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    SUM_FIELD_NUMBER: _ClassVar[int]
    path: str
    version: str
    sum: str
    def __init__(self, path: _Optional[str] = ..., version: _Optional[str] = ..., sum: _Optional[str] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from ibc.core.client.v1 import client_pb2 as _client_pb2
from ibc.core.connection.v1 import connection_pb2 as _connection_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryConnectionRequest(_message.Message):
    __slots__ = ("connection_id",)
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    connection_id: str
    def __init__(self, connection_id: _Optional[str] = ...) -> None: ...

class QueryConnectionResponse(_message.Message):
    __slots__ = ("connection", "proof", "proof_height")
    CONNECTION_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    connection: _connection_pb2.ConnectionEnd
    proof: bytes
    proof_height: _client_pb2.Height
    def __init__(self, connection: _Optional[_Union[_connection_pb2.ConnectionEnd, _Mapping]] = ..., proof: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryConnectionsRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryConnectionsResponse(_message.Message):
    __slots__ = ("connections", "pagination", "height")
    CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    connections: _containers.RepeatedCompositeFieldContainer[_connection_pb2.IdentifiedConnection]
    pagination: _pagination_pb2.PageResponse
    height: _client_pb2.Height
    def __init__(self, connections: _Optional[_Iterable[_Union[_connection_pb2.IdentifiedConnection, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ..., height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryClientConnectionsRequest(_message.Message):
    __slots__ = ("client_id",)
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    def __init__(self, client_id: _Optional[str] = ...) -> None: ...

class QueryClientConnectionsResponse(_message.Message):
    __slots__ = ("connection_paths", "proof", "proof_height")
    CONNECTION_PATHS_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    connection_paths: _containers.RepeatedScalarFieldContainer[str]
    proof: bytes
    proof_height: _client_pb2.Height
    def __init__(self, connection_paths: _Optional[_Iterable[str]] = ..., proof: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryConnectionClientStateRequest(_message.Message):
    __slots__ = ("connection_id",)
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    connection_id: str
    def __init__(self, connection_id: _Optional[str] = ...) -> None: ...

class QueryConnectionClientStateResponse(_message.Message):
    __slots__ = ("identified_client_state", "proof", "proof_height")
    IDENTIFIED_CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    identified_client_state: _client_pb2.IdentifiedClientState
    proof: bytes
    proof_height: _client_pb2.Height
    def __init__(self, identified_client_state: _Optional[_Union[_client_pb2.IdentifiedClientState, _Mapping]] = ..., proof: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryConnectionConsensusStateRequest(_message.Message):
    __slots__ = ("connection_id", "revision_number", "revision_height")
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    REVISION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    REVISION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    connection_id: str
    revision_number: int
    revision_height: int
    def __init__(self, connection_id: _Optional[str] = ..., revision_number: _Optional[int] = ..., revision_height: _Optional[int] = ...) -> None: ...

class QueryConnectionConsensusStateResponse(_message.Message):
    __slots__ = ("consensus_state", "client_id", "proof", "proof_height")
    CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    consensus_state: _any_pb2.Any
    client_id: str
    proof: bytes
    proof_height: _client_pb2.Height
    def __init__(self, consensus_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., client_id: _Optional[str] = ..., proof: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HashOp(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NO_HASH: _ClassVar[HashOp]
    SHA256: _ClassVar[HashOp]
    SHA512: _ClassVar[HashOp]
    KECCAK: _ClassVar[HashOp]
    RIPEMD160: _ClassVar[HashOp]
    BITCOIN: _ClassVar[HashOp]

class LengthOp(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NO_PREFIX: _ClassVar[LengthOp]
    VAR_PROTO: _ClassVar[LengthOp]
    VAR_RLP: _ClassVar[LengthOp]
    FIXED32_BIG: _ClassVar[LengthOp]
    FIXED32_LITTLE: _ClassVar[LengthOp]
    FIXED64_BIG: _ClassVar[LengthOp]
    FIXED64_LITTLE: _ClassVar[LengthOp]
    REQUIRE_32_BYTES: _ClassVar[LengthOp]
    REQUIRE_64_BYTES: _ClassVar[LengthOp]
NO_HASH: HashOp
SHA256: HashOp
SHA512: HashOp
KECCAK: HashOp
RIPEMD160: HashOp
BITCOIN: HashOp
NO_PREFIX: LengthOp
VAR_PROTO: LengthOp
VAR_RLP: LengthOp
FIXED32_BIG: LengthOp
FIXED32_LITTLE: LengthOp
FIXED64_BIG: LengthOp
FIXED64_LITTLE: LengthOp
REQUIRE_32_BYTES: LengthOp
REQUIRE_64_BYTES: LengthOp

class ExistenceProof(_message.Message):
    __slots__ = ("key", "value", "leaf", "path")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    LEAF_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    value: bytes
    leaf: LeafOp
    path: _containers.RepeatedCompositeFieldContainer[InnerOp]
    def __init__(self, key: _Optional[bytes] = ..., value: _Optional[bytes] = ..., leaf: _Optional[_Union[LeafOp, _Mapping]] = ..., path: _Optional[_Iterable[_Union[InnerOp, _Mapping]]] = ...) -> None: ...

class NonExistenceProof(_message.Message):
    __slots__ = ("key", "left", "right")
    KEY_FIELD_NUMBER: _ClassVar[int]
    LEFT_FIELD_NUMBER: _ClassVar[int]
    RIGHT_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    left: ExistenceProof
    right: ExistenceProof
    def __init__(self, key: _Optional[bytes] = ..., left: _Optional[_Union[ExistenceProof, _Mapping]] = ..., right: _Optional[_Union[ExistenceProof, _Mapping]] = ...) -> None: ...

class CommitmentProof(_message.Message):
    __slots__ = ("exist", "nonexist", "batch", "compressed")
    EXIST_FIELD_NUMBER: _ClassVar[int]
    NONEXIST_FIELD_NUMBER: _ClassVar[int]
    BATCH_FIELD_NUMBER: _ClassVar[int]
    COMPRESSED_FIELD_NUMBER: _ClassVar[int]
    exist: ExistenceProof
    nonexist: NonExistenceProof
    batch: BatchProof
    compressed: CompressedBatchProof
    def __init__(self, exist: _Optional[_Union[ExistenceProof, _Mapping]] = ..., nonexist: _Optional[_Union[NonExistenceProof, _Mapping]] = ..., batch: _Optional[_Union[BatchProof, _Mapping]] = ..., compressed: _Optional[_Union[CompressedBatchProof, _Mapping]] = ...) -> None: ...

class LeafOp(_message.Message):
    __slots__ = ("hash", "prehash_key", "prehash_value", "length", "prefix")
    HASH_FIELD_NUMBER: _ClassVar[int]
    PREHASH_KEY_FIELD_NUMBER: _ClassVar[int]
    PREHASH_VALUE_FIELD_NUMBER: _ClassVar[int]
    LENGTH_FIELD_NUMBER: _ClassVar[int]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    hash: HashOp
    prehash_key: HashOp
    prehash_value: HashOp
    length: LengthOp
    prefix: bytes
    def __init__(self, hash: _Optional[_Union[HashOp, str]] = ..., prehash_key: _Optional[_Union[HashOp, str]] = ..., prehash_value: _Optional[_Union[HashOp, str]] = ..., length: _Optional[_Union[LengthOp, str]] = ..., prefix: _Optional[bytes] = ...) -> None: ...

class InnerOp(_message.Message):
    __slots__ = ("hash", "prefix", "suffix")
    HASH_FIELD_NUMBER: _ClassVar[int]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    SUFFIX_FIELD_NUMBER: _ClassVar[int]
    hash: HashOp
    prefix: bytes
    suffix: bytes
    def __init__(self, hash: _Optional[_Union[HashOp, str]] = ..., prefix: _Optional[bytes] = ..., suffix: _Optional[bytes] = ...) -> None: ...

class ProofSpec(_message.Message):
    __slots__ = ("leaf_spec", "inner_spec", "max_depth", "min_depth")
    LEAF_SPEC_FIELD_NUMBER: _ClassVar[int]
    INNER_SPEC_FIELD_NUMBER: _ClassVar[int]
    MAX_DEPTH_FIELD_NUMBER: _ClassVar[int]
    MIN_DEPTH_FIELD_NUMBER: _ClassVar[int]
    leaf_spec: LeafOp
    inner_spec: InnerSpec
    max_depth: int
    min_depth: int
    def __init__(self, leaf_spec: _Optional[_Union[LeafOp, _Mapping]] = ..., inner_spec: _Optional[_Union[InnerSpec, _Mapping]] = ..., max_depth: _Optional[int] = ..., min_depth: _Optional[int] = ...) -> None: ...

class InnerSpec(_message.Message):
    __slots__ = ("child_order", "child_size", "min_prefix_length", "max_prefix_length", "empty_child", "hash")
    CHILD_ORDER_FIELD_NUMBER: _ClassVar[int]
    CHILD_SIZE_FIELD_NUMBER: _ClassVar[int]
    MIN_PREFIX_LENGTH_FIELD_NUMBER: _ClassVar[int]
    MAX_PREFIX_LENGTH_FIELD_NUMBER: _ClassVar[int]
    EMPTY_CHILD_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    child_order: _containers.RepeatedScalarFieldContainer[int]
    child_size: int
    min_prefix_length: int
    max_prefix_length: int
    empty_child: bytes
    hash: HashOp
    def __init__(self, child_order: _Optional[_Iterable[int]] = ..., child_size: _Optional[int] = ..., min_prefix_length: _Optional[int] = ..., max_prefix_length: _Optional[int] = ..., empty_child: _Optional[bytes] = ..., hash: _Optional[_Union[HashOp, str]] = ...) -> None: ...

class BatchProof(_message.Message):
    __slots__ = ("entries",)
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[BatchEntry]
    def __init__(self, entries: _Optional[_Iterable[_Union[BatchEntry, _Mapping]]] = ...) -> None: ...

class BatchEntry(_message.Message):
    __slots__ = ("exist", "nonexist")
    EXIST_FIELD_NUMBER: _ClassVar[int]
    NONEXIST_FIELD_NUMBER: _ClassVar[int]
    exist: ExistenceProof
    nonexist: NonExistenceProof
    def __init__(self, exist: _Optional[_Union[ExistenceProof, _Mapping]] = ..., nonexist: _Optional[_Union[NonExistenceProof, _Mapping]] = ...) -> None: ...

class CompressedBatchProof(_message.Message):
    __slots__ = ("entries", "lookup_inners")
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    LOOKUP_INNERS_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[CompressedBatchEntry]
    lookup_inners: _containers.RepeatedCompositeFieldContainer[InnerOp]
    def __init__(self, entries: _Optional[_Iterable[_Union[CompressedBatchEntry, _Mapping]]] = ..., lookup_inners: _Optional[_Iterable[_Union[InnerOp, _Mapping]]] = ...) -> None: ...

class CompressedBatchEntry(_message.Message):
    __slots__ = ("exist", "nonexist")
    EXIST_FIELD_NUMBER: _ClassVar[int]
    NONEXIST_FIELD_NUMBER: _ClassVar[int]
    exist: CompressedExistenceProof
    nonexist: CompressedNonExistenceProof
    def __init__(self, exist: _Optional[_Union[CompressedExistenceProof, _Mapping]] = ..., nonexist: _Optional[_Union[CompressedNonExistenceProof, _Mapping]] = ...) -> None: ...

class CompressedExistenceProof(_message.Message):
    __slots__ = ("key", "value", "leaf", "path")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    LEAF_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    value: bytes
    leaf: LeafOp
    path: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, key: _Optional[bytes] = ..., value: _Optional[bytes] = ..., leaf: _Optional[_Union[LeafOp, _Mapping]] = ..., path: _Optional[_Iterable[int]] = ...) -> None: ...

class CompressedNonExistenceProof(_message.Message):
    __slots__ = ("key", "left", "right")
    KEY_FIELD_NUMBER: _ClassVar[int]
    LEFT_FIELD_NUMBER: _ClassVar[int]
    RIGHT_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    left: CompressedExistenceProof
    right: CompressedExistenceProof
    def __init__(self, key: _Optional[bytes] = ..., left: _Optional[_Union[CompressedExistenceProof, _Mapping]] = ..., right: _Optional[_Union[CompressedExistenceProof, _Mapping]] = ...) -> None: ...



from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.protos.cosmos.staking.v1beta1.query_pb2 import (
    QueryDelegationRequest,
    QueryDelegationResponse,
    QueryDelegatorDelegationsRequest,
    QueryDelegatorDelegationsResponse,
    QueryDelegatorUnbondingDelegationsRequest,
    QueryDelegatorUnbondingDelegationsResponse,
    QueryDelegatorValidatorRequest,
    QueryDelegatorValidatorResponse,
    QueryDelegatorValidatorsRequest,
    QueryDelegatorValidatorsResponse,
    QueryHistoricalInfoRequest,
    QueryHistoricalInfoResponse,
    QueryParamsRequest,
    QueryParamsResponse,
    QueryPoolRequest,
    QueryPoolResponse,
    QueryRedelegationsRequest,
    QueryRedelegationsResponse,
    QueryUnbondingDelegationRequest,
    QueryUnbondingDelegationResponse,
    QueryValidatorDelegationsRequest,
    QueryValidatorDelegationsResponse,
    QueryValidatorRequest,
    QueryValidatorResponse,
    QueryValidatorUnbondingDelegationsRequest,
    QueryValidatorUnbondingDelegationsResponse,
    QueryValidatorsRequest,
    QueryValidatorsResponse,
)
from neurionpy.staking.interface import Staking


class StakingRestClient(Staking):
    """Staking REST client."""

    API_URL = "/cosmos/staking/v1beta1"

    def __init__(self, rest_api: RestClient) -> None:
        """
        Initialize.

        :param rest_api: RestClient api
        """
        self._rest_api = rest_api

    def Validators(self, request: QueryValidatorsRequest) -> QueryValidatorsResponse:
        """
        Query all validators that match the given status.

        :param request: QueryValidatorsRequest
        :return: QueryValidatorsResponse
        """
        json_response = self._rest_api.get(f"{self.API_URL}/validators", request)
        return Parse(json_response, QueryValidatorsResponse())

    def Validator(self, request: QueryValidatorRequest) -> QueryValidatorResponse:
        """
        Query validator info for given validator address.

        :param request: QueryValidatorRequest
        :return: QueryValidatorResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/validators/{request.validator_addr}",
        )
        return Parse(json_response, QueryValidatorResponse())

    def ValidatorDelegations(
        self, request: QueryValidatorDelegationsRequest
    ) -> QueryValidatorDelegationsResponse:
        """
        ValidatorDelegations queries delegate info for given validator.

        :param request: QueryValidatorDelegationsRequest
        :return: QueryValidatorDelegationsResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/validators/{request.validator_addr}/delegations",
            request,
            ["validatorAddr"],
        )
        return Parse(json_response, QueryValidatorDelegationsResponse())

    def ValidatorUnbondingDelegations(
        self, request: QueryValidatorUnbondingDelegationsRequest
    ) -> QueryValidatorUnbondingDelegationsResponse:
        """
        ValidatorUnbondingDelegations queries unbonding delegations of a validator.

        :param request: ValidatorUnbondingDelegations
        :return: QueryValidatorUnbondingDelegationsResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/validators/{request.validator_addr}/unbonding_delegations",
            request,
            ["validatorAddr"],
        )
        return Parse(json_response, QueryValidatorUnbondingDelegationsResponse())

    def Delegation(self, request: QueryDelegationRequest) -> QueryDelegationResponse:
        """
        Query delegate info for given validator delegator pair.

        :param request: QueryDelegationRequest
        :return: QueryDelegationResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/validators/{request.validator_addr}/delegations/{request.delegator_addr}",
        )
        return Parse(json_response, QueryDelegationResponse())

    def UnbondingDelegation(
        self, request: QueryUnbondingDelegationRequest
    ) -> QueryUnbondingDelegationResponse:
        """
        UnbondingDelegation queries unbonding info for given validator delegator pair.

        :param request: QueryUnbondingDelegationRequest
        :return: QueryUnbondingDelegationResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/validators/{request.validator_addr}/delegations/{request.delegator_addr}/unbonding_delegation",
        )
        return Parse(json_response, QueryUnbondingDelegationResponse())

    def DelegatorDelegations(
        self, request: QueryDelegatorDelegationsRequest
    ) -> QueryDelegatorDelegationsResponse:
        """
        DelegatorDelegations queries all delegations of a given delegator address.

        :param request: QueryDelegatorDelegationsRequest
        :return: QueryDelegatorDelegationsResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/delegations/{request.delegator_addr}",
            request,
            ["delegatorAddr"],
        )
        return Parse(json_response, QueryDelegatorDelegationsResponse())

    def DelegatorUnbondingDelegations(
        self, request: QueryDelegatorUnbondingDelegationsRequest
    ) -> QueryDelegatorUnbondingDelegationsResponse:
        """
        DelegatorUnbondingDelegations queries all unbonding delegations of a given delegator address.

        :param request: QueryDelegatorUnbondingDelegationsRequest
        :return: QueryDelegatorUnbondingDelegationsResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/delegators/{request.delegator_addr}/unbonding_delegations",
            request,
            ["delegatorAddr"],
        )
        return Parse(json_response, QueryDelegatorUnbondingDelegationsResponse())

    def Redelegations(
        self, request: QueryRedelegationsRequest
    ) -> QueryRedelegationsResponse:
        """
        Redelegations queries redelegations of given address.

        :param request: QueryRedelegationsRequest
        :return: QueryRedelegationsResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/delegators/{request.delegator_addr}/redelegations",
            request,
            ["delegatorAddr"],
        )
        return Parse(json_response, QueryRedelegationsResponse())

    def DelegatorValidators(
        self, request: QueryDelegatorValidatorsRequest
    ) -> QueryDelegatorValidatorsResponse:
        """
        DelegatorValidators queries all validators info for given delegator address.

        :param request: QueryDelegatorValidatorsRequest
        :return: QueryDelegatorValidatorsRequest
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/delegators/{request.delegator_addr}/validators",
            request,
            ["delegatorAddr"],
        )
        return Parse(json_response, QueryDelegatorValidatorsResponse())

    def DelegatorValidator(
        self, request: QueryDelegatorValidatorRequest
    ) -> QueryDelegatorValidatorResponse:
        """
        DelegatorValidator queries validator info for given delegator validator pair.

        :param request: QueryDelegatorValidatorRequest
        :return: QueryDelegatorValidatorResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/delegators/{request.delegator_addr}/validators/{request.validator_addr}",
        )
        return Parse(json_response, QueryDelegatorValidatorResponse())

    def HistoricalInfo(
        self, request: QueryHistoricalInfoRequest
    ) -> QueryHistoricalInfoResponse:
        """
        HistoricalInfo queries the historical info for given height.

        :param request: QueryHistoricalInfoRequest
        :return: QueryHistoricalInfoResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/historical_info/{request.height}"
        )
        return Parse(json_response, QueryHistoricalInfoResponse())

    def Pool(self, request: QueryPoolRequest) -> QueryPoolResponse:
        """
        Pool queries the pool info.

        :param request: QueryPoolRequest
        :return: QueryPoolResponse
        """
        json_response = self._rest_api.get(f"{self.API_URL}/pool")
        return Parse(json_response, QueryPoolResponse())

    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Parameters queries the staking parameters.

        :param request: QueryParamsRequest
        :return: QueryParamsResponse
        """
        json_response = self._rest_api.get(f"{self.API_URL}/params")
        return Parse(json_response, QueryParamsResponse())



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PlagiarismReportResult(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PLAGIARISM_REPORT_RESULT_NOT_AVAILABLE: _ClassVar[PlagiarismReportResult]
    PLAGIARISM_REPORT_RESULT_ACCEPTED: _ClassVar[PlagiarismReportResult]
    PLAGIARISM_REPORT_RESULT_REJECTED: _ClassVar[PlagiarismReportResult]
PLAGIARISM_REPORT_RESULT_NOT_AVAILABLE: PlagiarismReportResult
PLAGIARISM_REPORT_RESULT_ACCEPTED: PlagiarismReportResult
PLAGIARISM_REPORT_RESULT_REJECTED: PlagiarismReportResult

class PlagiarismReport(_message.Message):
    __slots__ = ("id", "task_id", "copied_submission_id", "suspected_submission_id", "arbitrator", "result", "created_timestamp", "decision_timestamp", "proof_of_plagiarism", "reason_for_rejection", "deposit", "reporter", "reportee")
    ID_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    COPIED_SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    SUSPECTED_SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    ARBITRATOR_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    CREATED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DECISION_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    PROOF_OF_PLAGIARISM_FIELD_NUMBER: _ClassVar[int]
    REASON_FOR_REJECTION_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    REPORTER_FIELD_NUMBER: _ClassVar[int]
    REPORTEE_FIELD_NUMBER: _ClassVar[int]
    id: int
    task_id: int
    copied_submission_id: int
    suspected_submission_id: int
    arbitrator: str
    result: PlagiarismReportResult
    created_timestamp: int
    decision_timestamp: int
    proof_of_plagiarism: str
    reason_for_rejection: str
    deposit: int
    reporter: str
    reportee: str
    def __init__(self, id: _Optional[int] = ..., task_id: _Optional[int] = ..., copied_submission_id: _Optional[int] = ..., suspected_submission_id: _Optional[int] = ..., arbitrator: _Optional[str] = ..., result: _Optional[_Union[PlagiarismReportResult, str]] = ..., created_timestamp: _Optional[int] = ..., decision_timestamp: _Optional[int] = ..., proof_of_plagiarism: _Optional[str] = ..., reason_for_rejection: _Optional[str] = ..., deposit: _Optional[int] = ..., reporter: _Optional[str] = ..., reportee: _Optional[str] = ...) -> None: ...



from amino import amino_pb2 as _amino_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from neurion.crucible import params_pb2 as _params_pb2
from neurion.crucible import task_pb2 as _task_pb2
from neurion.crucible import submission_pb2 as _submission_pb2
from neurion.crucible import plagiarism_report_pb2 as _plagiarism_report_pb2
from neurion.crucible import creator_application_pb2 as _creator_application_pb2
from neurion.crucible import score_task_pb2 as _score_task_pb2
from neurion.crucible import error_code_pb2 as _error_code_pb2
from neurion.crucible import dispute_score_task_pb2 as _dispute_score_task_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryGetCreatorsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryGetCreatorsResponse(_message.Message):
    __slots__ = ("creators",)
    CREATORS_FIELD_NUMBER: _ClassVar[int]
    creators: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, creators: _Optional[_Iterable[str]] = ...) -> None: ...

class QueryGetCreatorApplicationsRequest(_message.Message):
    __slots__ = ("creator",)
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    creator: str
    def __init__(self, creator: _Optional[str] = ...) -> None: ...

class QueryGetCreatorApplicationsResponse(_message.Message):
    __slots__ = ("applications",)
    APPLICATIONS_FIELD_NUMBER: _ClassVar[int]
    applications: _containers.RepeatedCompositeFieldContainer[_creator_application_pb2.CreatorApplication]
    def __init__(self, applications: _Optional[_Iterable[_Union[_creator_application_pb2.CreatorApplication, _Mapping]]] = ...) -> None: ...

class QueryGetTaskRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryGetTaskResponse(_message.Message):
    __slots__ = ("task",)
    TASK_FIELD_NUMBER: _ClassVar[int]
    task: _task_pb2.Task
    def __init__(self, task: _Optional[_Union[_task_pb2.Task, _Mapping]] = ...) -> None: ...

class QueryListAllTasksRequest(_message.Message):
    __slots__ = ("offset", "limit")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    offset: int
    limit: int
    def __init__(self, offset: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class QueryListAllTasksResponse(_message.Message):
    __slots__ = ("tasks", "pagination")
    TASKS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    tasks: _containers.RepeatedCompositeFieldContainer[_task_pb2.Task]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, tasks: _Optional[_Iterable[_Union[_task_pb2.Task, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryListTasksByStatusRequest(_message.Message):
    __slots__ = ("status", "offset", "limit")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    status: _task_pb2.TaskStatus
    offset: int
    limit: int
    def __init__(self, status: _Optional[_Union[_task_pb2.TaskStatus, str]] = ..., offset: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class QueryListTasksByStatusResponse(_message.Message):
    __slots__ = ("tasks", "pagination")
    TASKS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    tasks: _containers.RepeatedCompositeFieldContainer[_task_pb2.Task]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, tasks: _Optional[_Iterable[_Union[_task_pb2.Task, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryGetSubmissionRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryGetSubmissionResponse(_message.Message):
    __slots__ = ("submission",)
    SUBMISSION_FIELD_NUMBER: _ClassVar[int]
    submission: _submission_pb2.Submission
    def __init__(self, submission: _Optional[_Union[_submission_pb2.Submission, _Mapping]] = ...) -> None: ...

class QueryGetSubmissionByTaskCreatorRequest(_message.Message):
    __slots__ = ("task_id", "creator")
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    task_id: int
    creator: str
    def __init__(self, task_id: _Optional[int] = ..., creator: _Optional[str] = ...) -> None: ...

class QueryGetSubmissionByTaskCreatorResponse(_message.Message):
    __slots__ = ("final_submissions", "provisional_submissions")
    FINAL_SUBMISSIONS_FIELD_NUMBER: _ClassVar[int]
    PROVISIONAL_SUBMISSIONS_FIELD_NUMBER: _ClassVar[int]
    final_submissions: _containers.RepeatedCompositeFieldContainer[_submission_pb2.Submission]
    provisional_submissions: _containers.RepeatedCompositeFieldContainer[_submission_pb2.Submission]
    def __init__(self, final_submissions: _Optional[_Iterable[_Union[_submission_pb2.Submission, _Mapping]]] = ..., provisional_submissions: _Optional[_Iterable[_Union[_submission_pb2.Submission, _Mapping]]] = ...) -> None: ...

class QueryGetSubmissionByTaskRequest(_message.Message):
    __slots__ = ("task_id",)
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    task_id: int
    def __init__(self, task_id: _Optional[int] = ...) -> None: ...

class QueryGetSubmissionByTaskResponse(_message.Message):
    __slots__ = ("final_submissions", "provisional_submissions")
    FINAL_SUBMISSIONS_FIELD_NUMBER: _ClassVar[int]
    PROVISIONAL_SUBMISSIONS_FIELD_NUMBER: _ClassVar[int]
    final_submissions: _containers.RepeatedCompositeFieldContainer[_submission_pb2.Submission]
    provisional_submissions: _containers.RepeatedCompositeFieldContainer[_submission_pb2.Submission]
    def __init__(self, final_submissions: _Optional[_Iterable[_Union[_submission_pb2.Submission, _Mapping]]] = ..., provisional_submissions: _Optional[_Iterable[_Union[_submission_pb2.Submission, _Mapping]]] = ...) -> None: ...

class QueryGetEncryptedProofOfOwnershipRequest(_message.Message):
    __slots__ = ("key", "plaintext")
    KEY_FIELD_NUMBER: _ClassVar[int]
    PLAINTEXT_FIELD_NUMBER: _ClassVar[int]
    key: str
    plaintext: str
    def __init__(self, key: _Optional[str] = ..., plaintext: _Optional[str] = ...) -> None: ...

class QueryGetEncryptedProofOfOwnershipResponse(_message.Message):
    __slots__ = ("ciphertext",)
    CIPHERTEXT_FIELD_NUMBER: _ClassVar[int]
    ciphertext: str
    def __init__(self, ciphertext: _Optional[str] = ...) -> None: ...

class QueryGetPlagiarismReportRequest(_message.Message):
    __slots__ = ("report_id",)
    REPORT_ID_FIELD_NUMBER: _ClassVar[int]
    report_id: int
    def __init__(self, report_id: _Optional[int] = ...) -> None: ...

class QueryGetPlagiarismReportResponse(_message.Message):
    __slots__ = ("report",)
    REPORT_FIELD_NUMBER: _ClassVar[int]
    report: _plagiarism_report_pb2.PlagiarismReport
    def __init__(self, report: _Optional[_Union[_plagiarism_report_pb2.PlagiarismReport, _Mapping]] = ...) -> None: ...

class QueryGetTaskRewardRequest(_message.Message):
    __slots__ = ("task_id", "user")
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    task_id: int
    user: str
    def __init__(self, task_id: _Optional[int] = ..., user: _Optional[str] = ...) -> None: ...

class QueryGetTaskRewardResponse(_message.Message):
    __slots__ = ("reward",)
    REWARD_FIELD_NUMBER: _ClassVar[int]
    reward: int
    def __init__(self, reward: _Optional[int] = ...) -> None: ...

class QueryGetPendingCreatorApplicationsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryGetPendingCreatorApplicationsResponse(_message.Message):
    __slots__ = ("applicants",)
    APPLICANTS_FIELD_NUMBER: _ClassVar[int]
    applicants: _containers.RepeatedCompositeFieldContainer[_creator_application_pb2.CreatorApplication]
    def __init__(self, applicants: _Optional[_Iterable[_Union[_creator_application_pb2.CreatorApplication, _Mapping]]] = ...) -> None: ...

class QueryGetTaskStakeRequest(_message.Message):
    __slots__ = ("task_id", "user")
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    task_id: int
    user: str
    def __init__(self, task_id: _Optional[int] = ..., user: _Optional[str] = ...) -> None: ...

class QueryGetTaskStakeResponse(_message.Message):
    __slots__ = ("stake",)
    STAKE_FIELD_NUMBER: _ClassVar[int]
    stake: int
    def __init__(self, stake: _Optional[int] = ...) -> None: ...

class QueryGetUnscoredSubmissionsByTaskRequest(_message.Message):
    __slots__ = ("task_id",)
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    task_id: int
    def __init__(self, task_id: _Optional[int] = ...) -> None: ...

class QueryGetUnscoredSubmissionsByTaskResponse(_message.Message):
    __slots__ = ("submissions",)
    SUBMISSIONS_FIELD_NUMBER: _ClassVar[int]
    submissions: _containers.RepeatedCompositeFieldContainer[_submission_pb2.Submission]
    def __init__(self, submissions: _Optional[_Iterable[_Union[_submission_pb2.Submission, _Mapping]]] = ...) -> None: ...

class QueryCanTriggerFinalSubmissionRequest(_message.Message):
    __slots__ = ("creator", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryCanTriggerFinalSubmissionResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryCanTriggerFinalTestingRequest(_message.Message):
    __slots__ = ("creator", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryCanTriggerFinalTestingResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryCanRegisterAsTrainerRequest(_message.Message):
    __slots__ = ("user", "task_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryCanRegisterAsTrainerResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryCanRegisterAsScorerRequest(_message.Message):
    __slots__ = ("user", "task_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryCanRegisterAsScorerResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryIsTrainerRequest(_message.Message):
    __slots__ = ("user", "task_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryIsTrainerResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryIsScorerRequest(_message.Message):
    __slots__ = ("user", "task_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryIsScorerResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryCanSubmitTrainingResultRequest(_message.Message):
    __slots__ = ("user", "task_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryCanSubmitTrainingResultResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryCanSubmitFinalResultRequest(_message.Message):
    __slots__ = ("user", "task_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryCanSubmitFinalResultResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryCanRequestScoringTaskRequest(_message.Message):
    __slots__ = ("user", "task_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryCanRequestScoringTaskResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryGetPendingScoringTasksRequest(_message.Message):
    __slots__ = ("user", "task_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryGetPendingScoringTasksResponse(_message.Message):
    __slots__ = ("score_tasks",)
    SCORE_TASKS_FIELD_NUMBER: _ClassVar[int]
    score_tasks: _containers.RepeatedCompositeFieldContainer[_score_task_pb2.ScoreTask]
    def __init__(self, score_tasks: _Optional[_Iterable[_Union[_score_task_pb2.ScoreTask, _Mapping]]] = ...) -> None: ...

class QueryCanTerminateRequest(_message.Message):
    __slots__ = ("creator", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryCanTerminateResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryGetPlagiarismReportFromUserRequest(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: str
    def __init__(self, user: _Optional[str] = ...) -> None: ...

class QueryGetPlagiarismReportFromUserResponse(_message.Message):
    __slots__ = ("plagiarism_reports",)
    PLAGIARISM_REPORTS_FIELD_NUMBER: _ClassVar[int]
    plagiarism_reports: _containers.RepeatedCompositeFieldContainer[_plagiarism_report_pb2.PlagiarismReport]
    def __init__(self, plagiarism_reports: _Optional[_Iterable[_Union[_plagiarism_report_pb2.PlagiarismReport, _Mapping]]] = ...) -> None: ...

class QueryGetScoreDisputeFromUserRequest(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: str
    def __init__(self, user: _Optional[str] = ...) -> None: ...

class QueryGetScoreDisputeFromUserResponse(_message.Message):
    __slots__ = ("dispute_score_tasks",)
    DISPUTE_SCORE_TASKS_FIELD_NUMBER: _ClassVar[int]
    dispute_score_tasks: _containers.RepeatedCompositeFieldContainer[_dispute_score_task_pb2.DisputeScoreTask]
    def __init__(self, dispute_score_tasks: _Optional[_Iterable[_Union[_dispute_score_task_pb2.DisputeScoreTask, _Mapping]]] = ...) -> None: ...



from cosmos.app.v1alpha1 import module_pb2 as _module_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Module(_message.Message):
    __slots__ = ("authority",)
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    authority: str
    def __init__(self, authority: _Optional[str] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class StakeInfo(_message.Message):
    __slots__ = ("amount", "last_update_time", "weighted_stake")
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    LAST_UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    WEIGHTED_STAKE_FIELD_NUMBER: _ClassVar[int]
    amount: str
    last_update_time: int
    weighted_stake: str
    def __init__(self, amount: _Optional[str] = ..., last_update_time: _Optional[int] = ..., weighted_stake: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/services/block/v2/block_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/services/block/v2/block_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.services.block.v2 import block_pb2 as cometbft_dot_services_dot_block_dot_v2_dot_block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.cometbft/services/block/v2/block_service.proto\x12\x1a\x63ometbft.services.block.v2\x1a&cometbft/services/block/v2/block.proto2\xfc\x01\n\x0c\x42lockService\x12n\n\x0bGetByHeight\x12..cometbft.services.block.v2.GetByHeightRequest\x1a/.cometbft.services.block.v2.GetByHeightResponse\x12|\n\x0fGetLatestHeight\x12\x32.cometbft.services.block.v2.GetLatestHeightRequest\x1a\x33.cometbft.services.block.v2.GetLatestHeightResponse0\x01\x42=Z;github.com/cometbft/cometbft/api/cometbft/services/block/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.block.v2.block_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/cometbft/cometbft/api/cometbft/services/block/v2'
  _globals['_BLOCKSERVICE']._serialized_start=119
  _globals['_BLOCKSERVICE']._serialized_end=371
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from cometbft.crypto.v1 import proof_pb2 as _proof_pb2
from cometbft.version.v1 import types_pb2 as _types_pb2
from cometbft.types.v1beta1 import validator_pb2 as _validator_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SignedMsgType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SIGNED_MSG_TYPE_UNKNOWN: _ClassVar[SignedMsgType]
    SIGNED_MSG_TYPE_PREVOTE: _ClassVar[SignedMsgType]
    SIGNED_MSG_TYPE_PRECOMMIT: _ClassVar[SignedMsgType]
    SIGNED_MSG_TYPE_PROPOSAL: _ClassVar[SignedMsgType]
SIGNED_MSG_TYPE_UNKNOWN: SignedMsgType
SIGNED_MSG_TYPE_PREVOTE: SignedMsgType
SIGNED_MSG_TYPE_PRECOMMIT: SignedMsgType
SIGNED_MSG_TYPE_PROPOSAL: SignedMsgType

class PartSetHeader(_message.Message):
    __slots__ = ("total", "hash")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    total: int
    hash: bytes
    def __init__(self, total: _Optional[int] = ..., hash: _Optional[bytes] = ...) -> None: ...

class Part(_message.Message):
    __slots__ = ("index", "bytes", "proof")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    index: int
    bytes: bytes
    proof: _proof_pb2.Proof
    def __init__(self, index: _Optional[int] = ..., bytes: _Optional[bytes] = ..., proof: _Optional[_Union[_proof_pb2.Proof, _Mapping]] = ...) -> None: ...

class BlockID(_message.Message):
    __slots__ = ("hash", "part_set_header")
    HASH_FIELD_NUMBER: _ClassVar[int]
    PART_SET_HEADER_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    part_set_header: PartSetHeader
    def __init__(self, hash: _Optional[bytes] = ..., part_set_header: _Optional[_Union[PartSetHeader, _Mapping]] = ...) -> None: ...

class Header(_message.Message):
    __slots__ = ("version", "chain_id", "height", "time", "last_block_id", "last_commit_hash", "data_hash", "validators_hash", "next_validators_hash", "consensus_hash", "app_hash", "last_results_hash", "evidence_hash", "proposer_address")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    LAST_COMMIT_HASH_FIELD_NUMBER: _ClassVar[int]
    DATA_HASH_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_HASH_FIELD_NUMBER: _ClassVar[int]
    NEXT_VALIDATORS_HASH_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_HASH_FIELD_NUMBER: _ClassVar[int]
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    LAST_RESULTS_HASH_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_HASH_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    version: _types_pb2.Consensus
    chain_id: str
    height: int
    time: _timestamp_pb2.Timestamp
    last_block_id: BlockID
    last_commit_hash: bytes
    data_hash: bytes
    validators_hash: bytes
    next_validators_hash: bytes
    consensus_hash: bytes
    app_hash: bytes
    last_results_hash: bytes
    evidence_hash: bytes
    proposer_address: bytes
    def __init__(self, version: _Optional[_Union[_types_pb2.Consensus, _Mapping]] = ..., chain_id: _Optional[str] = ..., height: _Optional[int] = ..., time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., last_block_id: _Optional[_Union[BlockID, _Mapping]] = ..., last_commit_hash: _Optional[bytes] = ..., data_hash: _Optional[bytes] = ..., validators_hash: _Optional[bytes] = ..., next_validators_hash: _Optional[bytes] = ..., consensus_hash: _Optional[bytes] = ..., app_hash: _Optional[bytes] = ..., last_results_hash: _Optional[bytes] = ..., evidence_hash: _Optional[bytes] = ..., proposer_address: _Optional[bytes] = ...) -> None: ...

class Data(_message.Message):
    __slots__ = ("txs",)
    TXS_FIELD_NUMBER: _ClassVar[int]
    txs: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, txs: _Optional[_Iterable[bytes]] = ...) -> None: ...

class Vote(_message.Message):
    __slots__ = ("type", "height", "round", "block_id", "timestamp", "validator_address", "validator_index", "signature")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_INDEX_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    type: SignedMsgType
    height: int
    round: int
    block_id: BlockID
    timestamp: _timestamp_pb2.Timestamp
    validator_address: bytes
    validator_index: int
    signature: bytes
    def __init__(self, type: _Optional[_Union[SignedMsgType, str]] = ..., height: _Optional[int] = ..., round: _Optional[int] = ..., block_id: _Optional[_Union[BlockID, _Mapping]] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., validator_address: _Optional[bytes] = ..., validator_index: _Optional[int] = ..., signature: _Optional[bytes] = ...) -> None: ...

class Commit(_message.Message):
    __slots__ = ("height", "round", "block_id", "signatures")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    height: int
    round: int
    block_id: BlockID
    signatures: _containers.RepeatedCompositeFieldContainer[CommitSig]
    def __init__(self, height: _Optional[int] = ..., round: _Optional[int] = ..., block_id: _Optional[_Union[BlockID, _Mapping]] = ..., signatures: _Optional[_Iterable[_Union[CommitSig, _Mapping]]] = ...) -> None: ...

class CommitSig(_message.Message):
    __slots__ = ("block_id_flag", "validator_address", "timestamp", "signature")
    BLOCK_ID_FLAG_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    block_id_flag: _validator_pb2.BlockIDFlag
    validator_address: bytes
    timestamp: _timestamp_pb2.Timestamp
    signature: bytes
    def __init__(self, block_id_flag: _Optional[_Union[_validator_pb2.BlockIDFlag, str]] = ..., validator_address: _Optional[bytes] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., signature: _Optional[bytes] = ...) -> None: ...

class Proposal(_message.Message):
    __slots__ = ("type", "height", "round", "pol_round", "block_id", "timestamp", "signature")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    POL_ROUND_FIELD_NUMBER: _ClassVar[int]
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    type: SignedMsgType
    height: int
    round: int
    pol_round: int
    block_id: BlockID
    timestamp: _timestamp_pb2.Timestamp
    signature: bytes
    def __init__(self, type: _Optional[_Union[SignedMsgType, str]] = ..., height: _Optional[int] = ..., round: _Optional[int] = ..., pol_round: _Optional[int] = ..., block_id: _Optional[_Union[BlockID, _Mapping]] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., signature: _Optional[bytes] = ...) -> None: ...

class SignedHeader(_message.Message):
    __slots__ = ("header", "commit")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    COMMIT_FIELD_NUMBER: _ClassVar[int]
    header: Header
    commit: Commit
    def __init__(self, header: _Optional[_Union[Header, _Mapping]] = ..., commit: _Optional[_Union[Commit, _Mapping]] = ...) -> None: ...

class LightBlock(_message.Message):
    __slots__ = ("signed_header", "validator_set")
    SIGNED_HEADER_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SET_FIELD_NUMBER: _ClassVar[int]
    signed_header: SignedHeader
    validator_set: _validator_pb2.ValidatorSet
    def __init__(self, signed_header: _Optional[_Union[SignedHeader, _Mapping]] = ..., validator_set: _Optional[_Union[_validator_pb2.ValidatorSet, _Mapping]] = ...) -> None: ...

class BlockMeta(_message.Message):
    __slots__ = ("block_id", "block_size", "header", "num_txs")
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    BLOCK_SIZE_FIELD_NUMBER: _ClassVar[int]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NUM_TXS_FIELD_NUMBER: _ClassVar[int]
    block_id: BlockID
    block_size: int
    header: Header
    num_txs: int
    def __init__(self, block_id: _Optional[_Union[BlockID, _Mapping]] = ..., block_size: _Optional[int] = ..., header: _Optional[_Union[Header, _Mapping]] = ..., num_txs: _Optional[int] = ...) -> None: ...

class TxProof(_message.Message):
    __slots__ = ("root_hash", "data", "proof")
    ROOT_HASH_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    root_hash: bytes
    data: bytes
    proof: _proof_pb2.Proof
    def __init__(self, root_hash: _Optional[bytes] = ..., data: _Optional[bytes] = ..., proof: _Optional[_Union[_proof_pb2.Proof, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/vesting/v1beta1/vesting.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/vesting/v1beta1/vesting.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/vesting/v1beta1/vesting.proto\x12\x16\x63osmos.vesting.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\"\x89\x04\n\x12\x42\x61seVestingAccount\x12<\n\x0c\x62\x61se_account\x18\x01 \x01(\x0b\x32 .cosmos.auth.v1beta1.BaseAccountB\x04\xd0\xde\x1f\x01\x12\x80\x01\n\x10original_vesting\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBK\xc8\xde\x1f\x00\xf2\xde\x1f\x17yaml:\"original_vesting\"\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12|\n\x0e\x64\x65legated_free\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBI\xc8\xde\x1f\x00\xf2\xde\x1f\x15yaml:\"delegated_free\"\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x82\x01\n\x11\x64\x65legated_vesting\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBL\xc8\xde\x1f\x00\xf2\xde\x1f\x18yaml:\"delegated_vesting\"\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12%\n\x08\x65nd_time\x18\x05 \x01(\x03\x42\x13\xf2\xde\x1f\x0fyaml:\"end_time\":\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"\x9f\x01\n\x18\x43ontinuousVestingAccount\x12N\n\x14\x62\x61se_vesting_account\x18\x01 \x01(\x0b\x32*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01\x12)\n\nstart_time\x18\x02 \x01(\x03\x42\x15\xf2\xde\x1f\x11yaml:\"start_time\":\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"q\n\x15\x44\x65layedVestingAccount\x12N\n\x14\x62\x61se_vesting_account\x18\x01 \x01(\x0b\x32*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"{\n\x06Period\x12\x0e\n\x06length\x18\x01 \x01(\x03\x12[\n\x06\x61mount\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x04\x98\xa0\x1f\x00\"\xf6\x01\n\x16PeriodicVestingAccount\x12N\n\x14\x62\x61se_vesting_account\x18\x01 \x01(\x0b\x32*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01\x12)\n\nstart_time\x18\x02 \x01(\x03\x42\x15\xf2\xde\x1f\x11yaml:\"start_time\"\x12W\n\x0fvesting_periods\x18\x03 \x03(\x0b\x32\x1e.cosmos.vesting.v1beta1.PeriodB\x1e\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:\"vesting_periods\":\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"r\n\x16PermanentLockedAccount\x12N\n\x14\x62\x61se_vesting_account\x18\x01 \x01(\x0b\x32*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00\x42\x33Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.vesting.v1beta1.vesting_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/types'
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['base_account']._loaded_options = None
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['base_account']._serialized_options = b'\320\336\037\001'
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['original_vesting']._loaded_options = None
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['original_vesting']._serialized_options = b'\310\336\037\000\362\336\037\027yaml:\"original_vesting\"\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['delegated_free']._loaded_options = None
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['delegated_free']._serialized_options = b'\310\336\037\000\362\336\037\025yaml:\"delegated_free\"\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['delegated_vesting']._loaded_options = None
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['delegated_vesting']._serialized_options = b'\310\336\037\000\362\336\037\030yaml:\"delegated_vesting\"\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['end_time']._loaded_options = None
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['end_time']._serialized_options = b'\362\336\037\017yaml:\"end_time\"'
  _globals['_BASEVESTINGACCOUNT']._loaded_options = None
  _globals['_BASEVESTINGACCOUNT']._serialized_options = b'\210\240\037\000\230\240\037\000'
  _globals['_CONTINUOUSVESTINGACCOUNT'].fields_by_name['base_vesting_account']._loaded_options = None
  _globals['_CONTINUOUSVESTINGACCOUNT'].fields_by_name['base_vesting_account']._serialized_options = b'\320\336\037\001'
  _globals['_CONTINUOUSVESTINGACCOUNT'].fields_by_name['start_time']._loaded_options = None
  _globals['_CONTINUOUSVESTINGACCOUNT'].fields_by_name['start_time']._serialized_options = b'\362\336\037\021yaml:\"start_time\"'
  _globals['_CONTINUOUSVESTINGACCOUNT']._loaded_options = None
  _globals['_CONTINUOUSVESTINGACCOUNT']._serialized_options = b'\210\240\037\000\230\240\037\000'
  _globals['_DELAYEDVESTINGACCOUNT'].fields_by_name['base_vesting_account']._loaded_options = None
  _globals['_DELAYEDVESTINGACCOUNT'].fields_by_name['base_vesting_account']._serialized_options = b'\320\336\037\001'
  _globals['_DELAYEDVESTINGACCOUNT']._loaded_options = None
  _globals['_DELAYEDVESTINGACCOUNT']._serialized_options = b'\210\240\037\000\230\240\037\000'
  _globals['_PERIOD'].fields_by_name['amount']._loaded_options = None
  _globals['_PERIOD'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_PERIOD']._loaded_options = None
  _globals['_PERIOD']._serialized_options = b'\230\240\037\000'
  _globals['_PERIODICVESTINGACCOUNT'].fields_by_name['base_vesting_account']._loaded_options = None
  _globals['_PERIODICVESTINGACCOUNT'].fields_by_name['base_vesting_account']._serialized_options = b'\320\336\037\001'
  _globals['_PERIODICVESTINGACCOUNT'].fields_by_name['start_time']._loaded_options = None
  _globals['_PERIODICVESTINGACCOUNT'].fields_by_name['start_time']._serialized_options = b'\362\336\037\021yaml:\"start_time\"'
  _globals['_PERIODICVESTINGACCOUNT'].fields_by_name['vesting_periods']._loaded_options = None
  _globals['_PERIODICVESTINGACCOUNT'].fields_by_name['vesting_periods']._serialized_options = b'\310\336\037\000\362\336\037\026yaml:\"vesting_periods\"'
  _globals['_PERIODICVESTINGACCOUNT']._loaded_options = None
  _globals['_PERIODICVESTINGACCOUNT']._serialized_options = b'\210\240\037\000\230\240\037\000'
  _globals['_PERMANENTLOCKEDACCOUNT'].fields_by_name['base_vesting_account']._loaded_options = None
  _globals['_PERMANENTLOCKEDACCOUNT'].fields_by_name['base_vesting_account']._serialized_options = b'\320\336\037\001'
  _globals['_PERMANENTLOCKEDACCOUNT']._loaded_options = None
  _globals['_PERMANENTLOCKEDACCOUNT']._serialized_options = b'\210\240\037\000\230\240\037\000'
  _globals['_BASEVESTINGACCOUNT']._serialized_start=151
  _globals['_BASEVESTINGACCOUNT']._serialized_end=672
  _globals['_CONTINUOUSVESTINGACCOUNT']._serialized_start=675
  _globals['_CONTINUOUSVESTINGACCOUNT']._serialized_end=834
  _globals['_DELAYEDVESTINGACCOUNT']._serialized_start=836
  _globals['_DELAYEDVESTINGACCOUNT']._serialized_end=949
  _globals['_PERIOD']._serialized_start=951
  _globals['_PERIOD']._serialized_end=1074
  _globals['_PERIODICVESTINGACCOUNT']._serialized_start=1077
  _globals['_PERIODICVESTINGACCOUNT']._serialized_end=1323
  _globals['_PERMANENTLOCKEDACCOUNT']._serialized_start=1325
  _globals['_PERMANENTLOCKEDACCOUNT']._serialized_end=1439
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/base/v1beta1/coin.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/base/v1beta1/coin.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/base/v1beta1/coin.proto\x12\x13\x63osmos.base.v1beta1\x1a\x14gogoproto/gogo.proto\"8\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x1b\n\x06\x61mount\x18\x02 \x01(\tB\x0b\xc8\xde\x1f\x00\xda\xde\x1f\x03Int:\x04\xe8\xa0\x1f\x01\";\n\x07\x44\x65\x63\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x1b\n\x06\x61mount\x18\x02 \x01(\tB\x0b\xc8\xde\x1f\x00\xda\xde\x1f\x03\x44\x65\x63:\x04\xe8\xa0\x1f\x01\"$\n\x08IntProto\x12\x18\n\x03int\x18\x01 \x01(\tB\x0b\xc8\xde\x1f\x00\xda\xde\x1f\x03Int\"$\n\x08\x44\x65\x63Proto\x12\x18\n\x03\x64\x65\x63\x18\x01 \x01(\tB\x0b\xc8\xde\x1f\x00\xda\xde\x1f\x03\x44\x65\x63\x42,Z\"github.com/cosmos/cosmos-sdk/types\xd8\xe1\x1e\x00\x80\xe2\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.v1beta1.coin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\"github.com/cosmos/cosmos-sdk/types\330\341\036\000\200\342\036\000'
  _globals['_COIN'].fields_by_name['amount']._loaded_options = None
  _globals['_COIN'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\003Int'
  _globals['_COIN']._loaded_options = None
  _globals['_COIN']._serialized_options = b'\350\240\037\001'
  _globals['_DECCOIN'].fields_by_name['amount']._loaded_options = None
  _globals['_DECCOIN'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\003Dec'
  _globals['_DECCOIN']._loaded_options = None
  _globals['_DECCOIN']._serialized_options = b'\350\240\037\001'
  _globals['_INTPROTO'].fields_by_name['int']._loaded_options = None
  _globals['_INTPROTO'].fields_by_name['int']._serialized_options = b'\310\336\037\000\332\336\037\003Int'
  _globals['_DECPROTO'].fields_by_name['dec']._loaded_options = None
  _globals['_DECPROTO'].fields_by_name['dec']._serialized_options = b'\310\336\037\000\332\336\037\003Dec'
  _globals['_COIN']._serialized_start=77
  _globals['_COIN']._serialized_end=133
  _globals['_DECCOIN']._serialized_start=135
  _globals['_DECCOIN']._serialized_end=194
  _globals['_INTPROTO']._serialized_start=196
  _globals['_INTPROTO']._serialized_end=232
  _globals['_DECPROTO']._serialized_start=234
  _globals['_DECPROTO']._serialized_end=270
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from tendermint.crypto import keys_pb2 as _keys_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PacketPing(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PacketPong(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PacketMsg(_message.Message):
    __slots__ = ("channel_id", "eof", "data")
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    EOF_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    channel_id: int
    eof: bool
    data: bytes
    def __init__(self, channel_id: _Optional[int] = ..., eof: bool = ..., data: _Optional[bytes] = ...) -> None: ...

class Packet(_message.Message):
    __slots__ = ("packet_ping", "packet_pong", "packet_msg")
    PACKET_PING_FIELD_NUMBER: _ClassVar[int]
    PACKET_PONG_FIELD_NUMBER: _ClassVar[int]
    PACKET_MSG_FIELD_NUMBER: _ClassVar[int]
    packet_ping: PacketPing
    packet_pong: PacketPong
    packet_msg: PacketMsg
    def __init__(self, packet_ping: _Optional[_Union[PacketPing, _Mapping]] = ..., packet_pong: _Optional[_Union[PacketPong, _Mapping]] = ..., packet_msg: _Optional[_Union[PacketMsg, _Mapping]] = ...) -> None: ...

class AuthSigMessage(_message.Message):
    __slots__ = ("pub_key", "sig")
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    SIG_FIELD_NUMBER: _ClassVar[int]
    pub_key: _keys_pb2.PublicKey
    sig: bytes
    def __init__(self, pub_key: _Optional[_Union[_keys_pb2.PublicKey, _Mapping]] = ..., sig: _Optional[bytes] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class App(_message.Message):
    __slots__ = ("protocol", "software")
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_FIELD_NUMBER: _ClassVar[int]
    protocol: int
    software: str
    def __init__(self, protocol: _Optional[int] = ..., software: _Optional[str] = ...) -> None: ...

class Consensus(_message.Message):
    __slots__ = ("block", "app")
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    APP_FIELD_NUMBER: _ClassVar[int]
    block: int
    app: int
    def __init__(self, block: _Optional[int] = ..., app: _Optional[int] = ...) -> None: ...



from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from cosmos.staking.v1beta1 import staking_pb2 as _staking_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryValidatorsRequest(_message.Message):
    __slots__ = ("status", "pagination")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, status: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryValidatorsResponse(_message.Message):
    __slots__ = ("validators", "pagination")
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    validators: _containers.RepeatedCompositeFieldContainer[_staking_pb2.Validator]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, validators: _Optional[_Iterable[_Union[_staking_pb2.Validator, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryValidatorRequest(_message.Message):
    __slots__ = ("validator_addr",)
    VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    validator_addr: str
    def __init__(self, validator_addr: _Optional[str] = ...) -> None: ...

class QueryValidatorResponse(_message.Message):
    __slots__ = ("validator",)
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    validator: _staking_pb2.Validator
    def __init__(self, validator: _Optional[_Union[_staking_pb2.Validator, _Mapping]] = ...) -> None: ...

class QueryValidatorDelegationsRequest(_message.Message):
    __slots__ = ("validator_addr", "pagination")
    VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    validator_addr: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, validator_addr: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryValidatorDelegationsResponse(_message.Message):
    __slots__ = ("delegation_responses", "pagination")
    DELEGATION_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    delegation_responses: _containers.RepeatedCompositeFieldContainer[_staking_pb2.DelegationResponse]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, delegation_responses: _Optional[_Iterable[_Union[_staking_pb2.DelegationResponse, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryValidatorUnbondingDelegationsRequest(_message.Message):
    __slots__ = ("validator_addr", "pagination")
    VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    validator_addr: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, validator_addr: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryValidatorUnbondingDelegationsResponse(_message.Message):
    __slots__ = ("unbonding_responses", "pagination")
    UNBONDING_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    unbonding_responses: _containers.RepeatedCompositeFieldContainer[_staking_pb2.UnbondingDelegation]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, unbonding_responses: _Optional[_Iterable[_Union[_staking_pb2.UnbondingDelegation, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryDelegationRequest(_message.Message):
    __slots__ = ("delegator_addr", "validator_addr")
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    validator_addr: str
    def __init__(self, delegator_addr: _Optional[str] = ..., validator_addr: _Optional[str] = ...) -> None: ...

class QueryDelegationResponse(_message.Message):
    __slots__ = ("delegation_response",)
    DELEGATION_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    delegation_response: _staking_pb2.DelegationResponse
    def __init__(self, delegation_response: _Optional[_Union[_staking_pb2.DelegationResponse, _Mapping]] = ...) -> None: ...

class QueryUnbondingDelegationRequest(_message.Message):
    __slots__ = ("delegator_addr", "validator_addr")
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    validator_addr: str
    def __init__(self, delegator_addr: _Optional[str] = ..., validator_addr: _Optional[str] = ...) -> None: ...

class QueryUnbondingDelegationResponse(_message.Message):
    __slots__ = ("unbond",)
    UNBOND_FIELD_NUMBER: _ClassVar[int]
    unbond: _staking_pb2.UnbondingDelegation
    def __init__(self, unbond: _Optional[_Union[_staking_pb2.UnbondingDelegation, _Mapping]] = ...) -> None: ...

class QueryDelegatorDelegationsRequest(_message.Message):
    __slots__ = ("delegator_addr", "pagination")
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, delegator_addr: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryDelegatorDelegationsResponse(_message.Message):
    __slots__ = ("delegation_responses", "pagination")
    DELEGATION_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    delegation_responses: _containers.RepeatedCompositeFieldContainer[_staking_pb2.DelegationResponse]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, delegation_responses: _Optional[_Iterable[_Union[_staking_pb2.DelegationResponse, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryDelegatorUnbondingDelegationsRequest(_message.Message):
    __slots__ = ("delegator_addr", "pagination")
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, delegator_addr: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryDelegatorUnbondingDelegationsResponse(_message.Message):
    __slots__ = ("unbonding_responses", "pagination")
    UNBONDING_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    unbonding_responses: _containers.RepeatedCompositeFieldContainer[_staking_pb2.UnbondingDelegation]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, unbonding_responses: _Optional[_Iterable[_Union[_staking_pb2.UnbondingDelegation, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryRedelegationsRequest(_message.Message):
    __slots__ = ("delegator_addr", "src_validator_addr", "dst_validator_addr", "pagination")
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    SRC_VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    DST_VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    src_validator_addr: str
    dst_validator_addr: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, delegator_addr: _Optional[str] = ..., src_validator_addr: _Optional[str] = ..., dst_validator_addr: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryRedelegationsResponse(_message.Message):
    __slots__ = ("redelegation_responses", "pagination")
    REDELEGATION_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    redelegation_responses: _containers.RepeatedCompositeFieldContainer[_staking_pb2.RedelegationResponse]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, redelegation_responses: _Optional[_Iterable[_Union[_staking_pb2.RedelegationResponse, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryDelegatorValidatorsRequest(_message.Message):
    __slots__ = ("delegator_addr", "pagination")
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, delegator_addr: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryDelegatorValidatorsResponse(_message.Message):
    __slots__ = ("validators", "pagination")
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    validators: _containers.RepeatedCompositeFieldContainer[_staking_pb2.Validator]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, validators: _Optional[_Iterable[_Union[_staking_pb2.Validator, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryDelegatorValidatorRequest(_message.Message):
    __slots__ = ("delegator_addr", "validator_addr")
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    validator_addr: str
    def __init__(self, delegator_addr: _Optional[str] = ..., validator_addr: _Optional[str] = ...) -> None: ...

class QueryDelegatorValidatorResponse(_message.Message):
    __slots__ = ("validator",)
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    validator: _staking_pb2.Validator
    def __init__(self, validator: _Optional[_Union[_staking_pb2.Validator, _Mapping]] = ...) -> None: ...

class QueryHistoricalInfoRequest(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class QueryHistoricalInfoResponse(_message.Message):
    __slots__ = ("hist",)
    HIST_FIELD_NUMBER: _ClassVar[int]
    hist: _staking_pb2.HistoricalInfo
    def __init__(self, hist: _Optional[_Union[_staking_pb2.HistoricalInfo, _Mapping]] = ...) -> None: ...

class QueryPoolRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryPoolResponse(_message.Message):
    __slots__ = ("pool",)
    POOL_FIELD_NUMBER: _ClassVar[int]
    pool: _staking_pb2.Pool
    def __init__(self, pool: _Optional[_Union[_staking_pb2.Pool, _Mapping]] = ...) -> None: ...

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _staking_pb2.Params
    def __init__(self, params: _Optional[_Union[_staking_pb2.Params, _Mapping]] = ...) -> None: ...
